@@ -11,8 +11,20 @@
 
 #include "perl-backcompat.c.inc"
 
-void ClassPlain_class_apply_attribute(pTHX_ ClassMeta *class_meta, const char *name, SV *value)
-{
+ClassMeta *ClassPlain_create_class(pTHX_ IV type, SV* name) {
+  ClassMeta *class;
+  Newxz(class, 1, ClassMeta);
+
+  class->name = SvREFCNT_inc(name);
+
+  class->role_names = newAV();
+  class->fields = newAV();
+  class->methods = newAV();
+
+  return class;
+}
+
+void ClassPlain_class_apply_attribute(pTHX_ ClassMeta *class, const char *name, SV* value) {
   if(value && (!SvPOK(value) || !SvCUR(value))) {
     value = NULL;
   }
@@ -62,87 +74,97 @@ void ClassPlain_class_apply_attribute(pTHX_ ClassMeta *class_meta, const char *n
 
       // Push the super class to @ISA
       {
-        SV *isa_name = newSVpvf("%" SVf "::ISA", class_meta->name);
+        SV* isa_name = newSVpvf("%" SVf "::ISA", class->name);
         SAVEFREESV(isa_name);
         AV *isa = get_av(SvPV_nolen(isa_name), GV_ADD | (SvFLAGS(isa_name) & SVf_UTF8));
         av_push(isa, SvREFCNT_inc(super_class_name));
       }
     }
     else {
-      class_meta->isa_empty = 1;
+      class->isa_empty = 1;
     }
     
   }
+  // The does attribute
+  else if (strcmp(name, "does") == 0) {
+    SV* role_name = value;
+    ClassPlain_add_role_name(aTHX_ class, role_name);
+  }
   else {
     croak("Unrecognised class attribute :%s", name);
   }
 }
 
-MethodMeta *ClassPlain_class_add_method(pTHX_ ClassMeta *meta, SV *methodname)
-{
-  AV *methods = meta->methods;
-
-  if(!methodname || !SvOK(methodname) || !SvCUR(methodname))
-    croak("methodname must not be undefined or empty");
-
-  MethodMeta *methodmeta;
-  Newx(methodmeta, 1, MethodMeta);
-
-  methodmeta->name = SvREFCNT_inc(methodname);
-  methodmeta->class = meta;
-
-  av_push(methods, (SV *)methodmeta);
-
-  return methodmeta;
+void ClassPlain_add_role_name(pTHX_ ClassMeta* class, SV* role_name) {
+  AV *role_names = class->role_names;
+  
+  if (role_name) {
+    av_push(role_names, SvREFCNT_inc(role_name));
+  }
 }
 
-FieldMeta *ClassPlain_class_add_field(pTHX_ ClassMeta *meta, SV *field_name)
-{
-  AV *fields = meta->fields;
+void ClassPlain_begin_class_block(pTHX_ ClassMeta* class) {
+  SV* isa_name = newSVpvf("%" SVf "::ISA", class->name);
+  SAVEFREESV(isa_name);
+  AV *isa = get_av(SvPV_nolen(isa_name), GV_ADD | (SvFLAGS(isa_name) & SVf_UTF8));
+  
+  if (!class->isa_empty) {
+    if(!av_count(isa)) {
+      av_push(isa, newSVpvs("Class::Plain::Base"));
+    }
+  }
+
+  if (class->is_role) {
+    // The source code of Role::Tiny->import
+    SV* sv_source_code = sv_2mortal(newSVpv("", 0));
+    sv_catpv(sv_source_code, "{\n");
+    sv_catpv(sv_source_code, "  package ");
+    sv_catpv(sv_source_code, SvPV_nolen(class->name));
+    sv_catpv(sv_source_code, ";\n");
+    sv_catpv(sv_source_code, "  Role::Tiny->import;\n");
+    sv_catpv(sv_source_code, "}\n");
+    
+    // Role::Tiny->import
+    Perl_eval_pv(aTHX_ SvPV_nolen(sv_source_code), 1);
+  }
+}
+
+MethodMeta* ClassPlain_class_add_method(pTHX_ ClassMeta* class, SV* method_name) {
+  AV *methods = class->methods;
+
+  if(!method_name || !SvOK(method_name) || !SvCUR(method_name))
+    croak("method_name must not be undefined or empty");
+
+  MethodMeta* method;
+  Newx(method, 1, MethodMeta);
+
+  method->name = SvREFCNT_inc(method_name);
+  method->class = class;
+
+  av_push(methods, (SV*)method);
+  
+  return method;
+}
+
+FieldMeta* ClassPlain_class_add_field(pTHX_ ClassMeta* class, SV* field_name) {
+  AV *fields = class->fields;
 
   if(!field_name || !SvOK(field_name) || !SvCUR(field_name))
     croak("field_name must not be undefined or empty");
 
   U32 i;
   for(i = 0; i < av_count(fields); i++) {
-    FieldMeta *fieldmeta = (FieldMeta *)AvARRAY(fields)[i];
-    if(SvCUR(fieldmeta->name) < 2)
+    FieldMeta* field = (FieldMeta* )AvARRAY(fields)[i];
+    if(SvCUR(field->name) < 2)
       continue;
 
-    if(sv_eq(fieldmeta->name, field_name))
+    if(sv_eq(field->name, field_name))
       croak("Cannot add another field named %" SVf, field_name);
   }
 
-  FieldMeta *fieldmeta = ClassPlain_create_field(aTHX_ field_name, meta);
+  FieldMeta* field = ClassPlain_create_field(aTHX_ field_name, class);
 
-  av_push(fields, (SV *)fieldmeta);
+  av_push(fields, (SV*)field);
 
-  return fieldmeta;
-}
-
-ClassMeta *ClassPlain_create_class(pTHX_ IV type, SV *name)
-{
-  ClassMeta *meta;
-  Newx(meta, 1, ClassMeta);
-
-  meta->name = SvREFCNT_inc(name);
-
-  meta->fields = newAV();
-  meta->methods = newAV();
-  meta->isa_empty = 0;
-
-  return meta;
-}
-
-void ClassPlain_begin_class_block(pTHX_ ClassMeta *meta)
-{
-  SV *isa_name = newSVpvf("%" SVf "::ISA", meta->name);
-  SAVEFREESV(isa_name);
-  AV *isa = get_av(SvPV_nolen(isa_name), GV_ADD | (SvFLAGS(isa_name) & SVf_UTF8));
-  
-  if (!meta->isa_empty) {
-    if(!av_count(isa)) {
-      av_push(isa, newSVpvs("Class::Plain::Base"));
-    }
-  }
+  return field;
 }
