@@ -10,18 +10,18 @@
 
 void ClassPlain_need_PLparser(pTHX);
 
-FieldMeta *ClassPlain_create_field(pTHX_ SV *field_name, ClassMeta *class_meta)
+FieldMeta *ClassPlain_create_field(pTHX_ SV *field_name, ClassMeta *class)
 {
-  FieldMeta *fieldmeta;
-  Newx(fieldmeta, 1, FieldMeta);
+  FieldMeta *field;
+  Newxz(field, 1, FieldMeta);
 
-  fieldmeta->name = SvREFCNT_inc(field_name);
-  fieldmeta->class = class_meta;
+  field->name = SvREFCNT_inc(field_name);
+  field->class = class;
 
-  return fieldmeta;
+  return field;
 }
 
-void ClassPlain_field_apply_attribute(pTHX_ FieldMeta *fieldmeta, const char *name, SV *value)
+void ClassPlain_field_apply_attribute(pTHX_ FieldMeta *field, const char *name, SV *value)
 {
   if(value && (!SvPOK(value) || !SvCUR(value))) {
     value = NULL;
@@ -35,16 +35,16 @@ void ClassPlain_field_apply_attribute(pTHX_ FieldMeta *fieldmeta, const char *na
       // The reader code
       SV* sv_reader_code = sv_2mortal(newSVpv("", 0));
       sv_catpv(sv_reader_code, "sub ");
-      sv_catpv(sv_reader_code, SvPV_nolen(fieldmeta->class->name));
+      sv_catpv(sv_reader_code, SvPV_nolen(field->class->name));
       sv_catpv(sv_reader_code, "::");
       if (value) {
         sv_catpv(sv_reader_code, SvPV_nolen(value));
       }
       else {
-        sv_catpv(sv_reader_code, SvPV_nolen(fieldmeta->name));
+        sv_catpv(sv_reader_code, SvPV_nolen(field->name));
       }
       sv_catpv(sv_reader_code,  " {\n  my $self = shift;\n  $self->{");
-      sv_catpv(sv_reader_code, SvPV_nolen(fieldmeta->name));
+      sv_catpv(sv_reader_code, SvPV_nolen(field->name));
       sv_catpv(sv_reader_code, "};\n}");
       
       // Generate the reader
@@ -55,17 +55,17 @@ void ClassPlain_field_apply_attribute(pTHX_ FieldMeta *fieldmeta, const char *na
       // The writer code
       SV* sv_writer_code = sv_2mortal(newSVpv("", 0));
       sv_catpv(sv_writer_code, "sub ");
-      sv_catpv(sv_writer_code, SvPV_nolen(fieldmeta->class->name));
+      sv_catpv(sv_writer_code, SvPV_nolen(field->class->name));
       sv_catpv(sv_writer_code, "::");
       if (value) {
         sv_catpv(sv_writer_code, SvPV_nolen(value));
       }
       else {
         sv_catpv(sv_writer_code, "set_");
-        sv_catpv(sv_writer_code, SvPV_nolen(fieldmeta->name));
+        sv_catpv(sv_writer_code, SvPV_nolen(field->name));
       }
       sv_catpv(sv_writer_code,  " {\n  my $self = shift;\n  $self->{");
-      sv_catpv(sv_writer_code, SvPV_nolen(fieldmeta->name));
+      sv_catpv(sv_writer_code, SvPV_nolen(field->name));
       sv_catpv(sv_writer_code, "} = shift;\n  return $self;\n}");
       
       // Generate the writer
@@ -76,19 +76,19 @@ void ClassPlain_field_apply_attribute(pTHX_ FieldMeta *fieldmeta, const char *na
       // The rw code
       SV* sv_rw_code = sv_2mortal(newSVpv("", 0));
       sv_catpv(sv_rw_code, "sub ");
-      sv_catpv(sv_rw_code, SvPV_nolen(fieldmeta->class->name));
+      sv_catpv(sv_rw_code, SvPV_nolen(field->class->name));
       sv_catpv(sv_rw_code, "::");
       if (value) {
         sv_catpv(sv_rw_code, SvPV_nolen(value));
       }
       else {
-        sv_catpv(sv_rw_code, SvPV_nolen(fieldmeta->name));
+        sv_catpv(sv_rw_code, SvPV_nolen(field->name));
       }
       sv_catpv(sv_rw_code,  " {\n  my $self = shift;\n  if (@_) {\n  $self->{");
-      sv_catpv(sv_rw_code, SvPV_nolen(fieldmeta->name));
+      sv_catpv(sv_rw_code, SvPV_nolen(field->name));
       sv_catpv(sv_rw_code, "} = shift;\n  return $self;\n }\n");
       sv_catpv(sv_rw_code,  "$self->{");
-      sv_catpv(sv_rw_code, SvPV_nolen(fieldmeta->name));
+      sv_catpv(sv_rw_code, SvPV_nolen(field->name));
       sv_catpv(sv_rw_code, "};\n}");
       
       // Generate the rw
